@@ -3,6 +3,7 @@ Module file that contains a FigPager class. A static function float_list_value i
 Currently PDF and PGF are supported in a multipage backend.
 
 Written by Eben Pendleton
+MIT License
 """
 # used to deep copy config
 import copy
@@ -12,6 +13,11 @@ import datetime
 import inspect
 import os
 
+import matplotlib as mpl
+if os.environ.get('DISPLAY','') == '':
+    print('no display found. Using non-interactive Agg backend')
+    mpl.use('Agg')
+
 # used to drwa lines on the figure
 import matplotlib.lines as lines
 # matplotlib import used in setting figure and axes
@@ -28,6 +34,7 @@ import configobj
 # import the validator
 from validate import Validator
 
+
 # set up the base string depending if we are running Python 2 or Python 3
 try:
     # check whether python knows about 'basestring'
@@ -89,6 +96,8 @@ class FigPager:
         subplotstartindex=None,
         direction="left-to-right",
         overwrite=False,
+        sharex=False,
+        sharey=False,
     ):
 
         """
@@ -116,6 +125,8 @@ class FigPager:
             subplotstartindex: (list of ints) (optional) First subplot on a page row and column index.
             direction: (string) (optional) subplot creation direction. Default is left-to-right.
             overwrite: (boolean) (optional) Boolean on whether to overwrite existing output. Default is True
+            sharex: share x axes in subplots. Default is False
+            sharey:share y axes in subplots.Default is False
         """
 
         # obtain the caller path
@@ -204,7 +215,6 @@ class FigPager:
 
             self.orientation = orientation
             self.paper_size = paper_size
-            self.papertype = paper_size
 
             # update the orientation based on paper size
             self._set_paper_size_orientation()
@@ -214,6 +224,8 @@ class FigPager:
         self.ncols = ncols
         self.height_ratios = height_ratios
         self.width_ratios = width_ratios
+        self.sharex = sharex
+        self.sharey = sharey
 
         # figure attributes
         self.fig = None
@@ -835,7 +847,7 @@ class FigPager:
         fig, ax = plt.subplots(
             constrained_layout=self.constrained_layout,
             figsize=(self.pagewidth_inch, self.pageheight_inch),
-            squeeze=False,
+            squeeze=False, sharex=self.sharex, sharey=self.sharey,
         )
 
         # set the patch here
@@ -1082,7 +1094,6 @@ class FigPager:
         bbox_inches=None,
         pad_inches=None,
         metadata=None,
-        papertype=None,
         subplotstartindex=None,
         direction="left-to-right",
     ):
@@ -1166,9 +1177,6 @@ class FigPager:
         if metadata is not None:
             self.metadata = metadata
 
-        if papertype is not None:
-            self.papertype = papertype
-
         if subplotstartindex == [0, 0] or subplotstartindex is None:
             self.subplotstartindex = None
         else:
@@ -1190,7 +1198,6 @@ class FigPager:
                     facecolor=self.facecolor,
                     edgecolor=self.edgecolor,
                     orientation=self.orientation,
-                    papertype=self.papertype,
                     transparent=self.transparent,
                     bbox_inches=self.bbox_inches,
                     pad_inches=self.pad_inches,
@@ -1207,7 +1214,6 @@ class FigPager:
                 facecolor=self.facecolor,
                 edgecolor=self.edgecolor,
                 orientation=self.orientation,
-                papertype=self.papertype,
                 transparent=self.transparent,
                 bbox_inches=self.bbox_inches,
                 pad_inches=self.pad_inches,
@@ -1242,7 +1248,6 @@ class FigPager:
                     facecolor=self.facecolor,
                     edgecolor=self.edgecolor,
                     orientation=self.orientation,
-                    papertype=self.papertype,
                     transparent=self.transparent,
                     bbox_inches=self.bbox_inches,
                     pad_inches=self.pad_inches,
@@ -1255,7 +1260,6 @@ class FigPager:
                     facecolor=self.facecolor,
                     edgecolor=self.edgecolor,
                     orientation=self.orientation,
-                    papertype=self.papertype,
                     transparent=self.transparent,
                     bbox_inches=self.bbox_inches,
                     pad_inches=self.pad_inches,
